@@ -3,7 +3,7 @@
  *  BlueZ - Bluetooth protocol stack for Linux
  *
  *  Copyright (C) 2001-2002  Ricky Yuen <ryuen@qualcomm.com>
- *  Copyright (C) 2003-2006  Marcel Holtmann <marcel@holtmann.org>
+ *  Copyright (C) 2003-2011  Marcel Holtmann <marcel@holtmann.org>
  *
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -33,11 +33,8 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include <sys/types.h>
-#include <netinet/in.h>
-
-#include "parser.h"
-#include "sdp.h"
+#include "parser/parser.h"
+#include "parser/sdp.h"
 
 #define SDP_ERROR_RSP                                  0x01
 #define SDP_SERVICE_SEARCH_REQ                         0x02
@@ -194,8 +191,8 @@ static sdp_attr_id_nam_lookup_table_t sdp_attr_id_nam_lookup_table[] = {
 	{ SDP_ATTR_ID_BLUETOOTH_PROFILE_DESCRIPTOR_LIST, "BTProfileDescList"  },
 	{ SDP_ATTR_ID_DOCUMENTATION_URL,                 "DocURL"             },
 	{ SDP_ATTR_ID_CLIENT_EXECUTABLE_URL,             "ClientExeURL"       },
-	{ SDP_ATTR_ID_ICON_10,                           "Icon10"             },
 	{ SDP_ATTR_ID_ICON_URL,                          "IconURL"            },
+	{ SDP_ATTR_ID_ADDITIONAL_PROTOCOL_DESC_LISTS,    "AdditionalProtocolDescLists" },
 	{ SDP_ATTR_ID_SERVICE_NAME,                      "SrvName"            },
 	{ SDP_ATTR_ID_SERVICE_DESCRIPTION,               "SrvDesc"            },
 	{ SDP_ATTR_ID_PROVIDER_NAME,                     "ProviderName"       },
@@ -222,7 +219,7 @@ static sdp_attr_id_nam_lookup_table_t sdp_attr_id_nam_lookup_table[] = {
 
 char* get_uuid_name(int uuid)
 {
-	int i;
+	unsigned int i;
 
 	for (i = 0; i < SDP_UUID_NAM_LOOKUP_TABLE_SIZE; i++) {
 		if (sdp_uuid_nam_lookup_table[i].uuid == uuid)
@@ -234,7 +231,7 @@ char* get_uuid_name(int uuid)
 
 static inline char* get_attr_id_name(int attr_id)
 {
-	int i;
+	unsigned int i;
 
 	for (i = 0; i < SDP_ATTR_ID_NAM_LOOKUP_TABLE_SIZE; i++)
 		if (sdp_attr_id_nam_lookup_table[i].attr_id == attr_id)
@@ -399,7 +396,7 @@ static inline void print_de(int, struct frame *frm, int *split, uint16_t *psm, u
 static inline void print_des(uint8_t de_type, int level, int n, struct frame *frm, int *split, uint16_t *psm, uint8_t *channel)
 {
 	int len = frm->len;
-	while (len - frm->len < n && frm->len > 0)
+	while (len - (int) frm->len < n && (int) frm->len > 0)
 		print_de(level, frm, split, psm, channel);
 }
 
@@ -455,7 +452,7 @@ static inline void print_srv_srch_pat(int level, struct frame *frm)
 
 	if (parse_de_hdr(frm, &n1) == SDP_DE_SEQ) {
 		len = frm->len;
-		while (len - frm->len < n1 && frm->len > 0) {
+		while (len - (int) frm->len < n1 && (int) frm->len > 0) {
 			if (parse_de_hdr(frm, &n2) == SDP_DE_UUID) {
 				print_uuid(n2, frm, NULL, NULL);
 			} else {
@@ -481,7 +478,7 @@ static inline void print_attr_id_list(int level, struct frame *frm)
 
 	if (parse_de_hdr(frm, &n1) == SDP_DE_SEQ) {
 		len = frm->len;
-		while (len - frm->len < n1 && frm->len > 0) {
+		while (len - (int) frm->len < n1 && (int) frm->len > 0) {
 			/* Print AttributeID */
 			if (parse_de_hdr(frm, &n2) == SDP_DE_UINT) {
 				char *name;
@@ -520,7 +517,7 @@ static inline void print_attr_list(int level, struct frame *frm)
 
 	if (parse_de_hdr(frm, &n1) == SDP_DE_SEQ) {
 		len = frm->len;
-		while (len - frm->len < n1 && frm->len > 0) {
+		while (len - (int) frm->len < n1 && (int) frm->len > 0) {
 			/* Print AttributeID */
 			if (parse_de_hdr(frm, &n2) == SDP_DE_UINT && n2 == sizeof(attr_id)) {
 				char *name;
@@ -558,7 +555,7 @@ static inline void print_attr_lists(int level, struct frame *frm)
 	int count = frm->len;
 
 	if (parse_de_hdr(frm, &n) == SDP_DE_SEQ) {
-		while (count - frm->len < n && frm->len > 0) {
+		while (count - (int) frm->len < n && (int) frm->len > 0) {
 			p_indent(level, 0);
 			printf("record #%d\n", cnt++);
 			print_attr_list(level + 2, frm);
