@@ -2,7 +2,7 @@
  *
  *  BlueZ - Bluetooth protocol stack for Linux
  *
- *  Copyright (C) 2004-2007  Marcel Holtmann <marcel@holtmann.org>
+ *  Copyright (C) 2004-2011  Marcel Holtmann <marcel@holtmann.org>
  *
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -34,9 +34,9 @@
 #include <sys/ioctl.h>
 #include <sys/socket.h>
 
-#include <bluetooth/bluetooth.h>
-#include <bluetooth/hci.h>
-#include <bluetooth/hci_lib.h>
+#include "parser/parser.h"
+#include "lib/hci.h"
+#include "lib/hci_lib.h"
 
 static volatile sig_atomic_t __io_canceled = 0;
 
@@ -215,7 +215,7 @@ int main(int argc, char *argv[])
 		exit(1);
 	}
 
-	if (ver.err != 10 || id2ver(ver.hci_rev) < 0) {
+	if (ver.manufacturer != 10 || id2ver(ver.hci_rev) < 0) {
 		fprintf(stderr, "Can't find sniffer at hci%d: %s (%d)\n",
 						dev, strerror(ENOSYS), ENOSYS);
 		hci_close_dev(dd);
