@@ -39,19 +39,17 @@
 #include <sys/ioctl.h>
 #include <sys/socket.h>
 
-#include <bluetooth/bluetooth.h>
-#include <bluetooth/hci.h>
-#include <bluetooth/hci_lib.h>
-
 #include <arpa/inet.h>
-#include <netinet/in.h>
 #include <netdb.h>
 
 #include "parser/parser.h"
 #include "parser/sdp.h"
 
-#define SNAP_LEN 	HCI_MAX_FRAME_SIZE
-#define DEFAULT_PORT	"10839";
+#include "lib/hci.h"
+#include "lib/hci_lib.h"
+
+#define SNAP_LEN	HCI_MAX_FRAME_SIZE
+#define DEFAULT_PORT   "10839"
 
 /* Modes */
 enum {
@@ -804,6 +802,7 @@ static struct {
 	{ "hci",	FILT_HCI	},
 	{ "sco",	FILT_SCO	},
 	{ "l2cap",	FILT_L2CAP	},
+	{ "a2mp",	FILT_A2MP	},
 	{ "rfcomm",	FILT_RFCOMM	},
 	{ "sdp",	FILT_SDP	},
 	{ "bnep",	FILT_BNEP	},
@@ -817,6 +816,7 @@ static struct {
 	{ "obex",	FILT_OBEX	},
 	{ "capi",	FILT_CAPI	},
 	{ "ppp",	FILT_PPP	},
+	{ "sap",	FILT_SAP	},
 	{ "csr",	FILT_CSR	},
 	{ "dga",	FILT_DGA	},
 	{ 0 }
@@ -857,8 +857,9 @@ static void usage(void)
 	"  -R, --raw                  Dump raw data\n"
 	"  -C, --cmtp=psm             PSM for CMTP\n"
 	"  -H, --hcrp=psm             PSM for HCRP\n"
-	"  -O, --obex=channel         Channel for OBEX\n"
+	"  -O, --obex=port            Channel/PSM for OBEX\n"
 	"  -P, --ppp=channel          Channel for PPP\n"
+	"  -S, --sap=channel          Channel for SAP\n"
 	"  -D, --pppdump=file         Extract PPP traffic\n"
 	"  -A, --audio=file           Extract SCO audio data\n"
 	"  -Y, --novendor             No vendor commands or events\n"
@@ -887,6 +888,7 @@ static struct option main_options[] = {
 	{ "hcrp",		1, 0, 'H' },
 	{ "obex",		1, 0, 'O' },
 	{ "ppp",		1, 0, 'P' },
+	{ "sap",		1, 0, 'S' },
 	{ "pppdump",		1, 0, 'D' },
 	{ "audio",		1, 0, 'A' },
 	{ "novendor",		0, 0, 'Y' },
@@ -906,8 +908,11 @@ int main(int argc, char *argv[])
 	int defpsm = 0;
 	int defcompid = DEFAULT_COMPID;
 	int opt, pppdump_fd = -1, audio_fd = -1;
+	uint16_t obex_port;
 
-	while ((opt=getopt_long(argc, argv, "i:l:p:m:w:r:d:taxXRC:H:O:P:D:A:YZ46hv", main_options, NULL)) != -1) {
+	while ((opt = getopt_long(argc, argv,
+				"i:l:p:m:w:r:d:taxXRC:H:O:P:S:D:A:YZ46hv",
+				main_options, NULL)) != -1) {
 		switch(opt) {
 		case 'i':
 			if (strcasecmp(optarg, "none") && strcasecmp(optarg, "system"))
@@ -972,13 +977,21 @@ int main(int argc, char *argv[])
 			break;
 
 		case 'O':
-			set_proto(0, 0, atoi(optarg), SDP_UUID_OBEX);
+			obex_port = atoi(optarg);
+			if (obex_port > 31)
+				set_proto(0, obex_port, 0, SDP_UUID_OBEX);
+			else
+				set_proto(0, 0, obex_port, SDP_UUID_OBEX);
 			break;
 
 		case 'P':
 			set_proto(0, 0, atoi(optarg), SDP_UUID_LAN_ACCESS_PPP);
 			break;
 
+		case 'S':
+			set_proto(0, 0, atoi(optarg), SDP_UUID_SIM_ACCESS);
+			break;
+
 		case 'D':
 			pppdump_file = strdup(optarg);
 			break;
